%% INITIALIZE
%------------------------------------------------------------------------%
%**** Start panel. 
%-! Set cases to load from OpenFOAM raw data.
%-! Set information about probe coordinates.
%-! Choose time directory. 
%-!
%-! ||  Case Name   |  Case number  |  Case Name   |  Case number ||
%-! ----------------------------------------------------------------
%-! |    M01               1               C01            8        |
%-! |    M02               2               C02            9        |
%-! |    M03               3               C03           10        |
%-! |    M04               4               C04           11        |
%-! |    M05               5               S01           12        |
%-! |    M06               6               S02           13        |
%-! |    M07               7               S03           14        |
%-! '--------------------------------------------------------------'
%-!
%------------------------------------------------------------------------%
clear all
close all
clc

caseNames = ["M01","M02","M03","M04","M05","M06","M07","C01","C02",...
    "C03","C04","S01","S02","S03"];
timeDirs = ["500","100","100","100","100","100","100","1500","1600",...
    "0","100","100","100","100"];
Uinf = [5 5 5 5 5 5 5 2 5 2 5 3.5 3.5 4.5]; % Normalization velocity
normCorrCoeff = 1; % Correction for wrong force normalization.
R = 12; % Cylinder radius of curvature (Inner)
D = 1; % Cylinder diameter

% Correction coefficients used for normalization in total force signal
curveCorrCoeff = 1; %12/19 for M-series
horCorrCoeff = 1; % 10/19 for M-series
verCorrCoeff = 1; % 6/19 for M-series

startVec = [1 1 1 1 1 1 1 1 1 100 1 1 1 1];
dThetaUni = [4.5 4.5 4.5 4.5 4.5 4.5 4.5 2.25 2.25 4.5 4.5 2.25 2.25 2.25];
dThetaFine = [0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5 0.5];

zVerStart1D = [0.6 0.6 0.6 0.6 0.6 0.6 0.6 0 0 0.6 0.6 0 0 0];
zVerEnd1D = [6 6 6 6 6 6 6 24 24 6 6 24 24 24];

zVerStart3D = [0 0 0 0 0 0 0 0 0 0 0 0 0 0];
zVerEnd3D = [6 6 6 6 6 6 6 24 24 6 6 24 24 24];

dZ1D = [0.6 0.6 0.6 0.6 0.6 0.6 0.6 0.5 0.5 0.6 0.6 0.5 0.5 0.5];
dZ3D = [1 1 1 1 1 1 1 0.5 0.5 1 1 0.5 0.5 0.5];

%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Start-time for statistics in rows
forceStarts = startVec; 
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Representing [curve hor ver tot]
parts = [1 2 3 4]; 
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Uniform curve
uniStart = startVec;      % Start-row for statistics in each case.
uniThetaStartDeg = 0;
uniThetaEndDeg = 90;
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Upper fine curve
fineStart = startVec;       % Start-row for statistics in each case.
fineThetaStartDeg = 80;
fineThetaEndDeg = 90;
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Vertical 1D
ver1DStart = startVec;      % Start-row for statistics in each case.
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%
% Vertical 3D
ver3DStart = startVec;      % Start-row for statistics in each case.
%~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~%



%% INITIALIZE COORDINATE CELL ARRAYS
nCases = length(caseNames);

uniThetaDeg = cell([nCases,1]);
fineThetaDeg = cell([nCases,1]);
zVer1D = cell([nCases,1]);
zVer3D = cell([nCases,1]);
uniThetaRad = cell([nCases,1]);
sOverD = cell([nCases,1]);
fineThetaRad = cell([nCases,1]);
for i = 1:nCases
    uniThetaDeg{i} = uniThetaStartDeg:dThetaUni(i):uniThetaEndDeg;
    fineThetaDeg{i} = fineThetaStartDeg:dThetaFine(i):fineThetaEndDeg; 
    zVer1D{i} = zVerStart1D(i):dZ1D(i):zVerEnd1D(i);
    zVer3D{i} = zVerStart3D(i):dZ3D(i):zVerEnd3D(i);
    uniThetaRad{i} = uniThetaDeg{i}*pi/180;
    sOverD{i} = uniThetaRad{i}*(R+D/2);
    fineThetaRad{i} = fineThetaDeg{i}*pi/180;
end

%% GET FORCE COEFFICIENTS DATA
%------------------------------------------------------------------------%
%**** Get force coefficients data.
%-! Move relevant files to directory set in 'forceDir'.
%-! 
%------------------------------------------------------------------------%
forceDir = 'forceCoeffsAnalysis/';

if (exist('forceCoeffsAnalysis','dir'))
    rmdir forceCoeffsAnalysis s
    mkdir forceCoeffsAnalysis/
else
    mkdir forceCoeffsAnalysis
end

% curveForces
% Names ex.: curveForcesM01.dat
curveForcesFilePaths = strings(1,nCases);
curveForcesCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,curveForcesFilePaths(i)] = fileMover(caseNames(i),'curveForces',timeDirs(i), ...
    'forceCoeffs.dat',join(['curveForces' caseNames(i)],""),forceDir);
    curveForcesCellArray{i} = importdata(curveForcesFilePaths(i));
end

% horForces
% Names ex.: horForcesM01.dat
horForcesFilePaths = strings(1,nCases);
horForcesCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,horForcesFilePaths(i)] = fileMover(caseNames(i),'horForces',timeDirs(i), ...
    'forceCoeffs.dat',join(['horForces' caseNames(i)],""),forceDir);
    horForcesCellArray{i} = importdata(horForcesFilePaths(i));
end

% verForces
% Names ex.: verForcesM01.dat
verForcesFilePaths = strings(1,nCases);
verForcesCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,verForcesFilePaths(i)] = fileMover(caseNames(i),'verForces',timeDirs(i), ...
    'forceCoeffs.dat',join(['verForces' caseNames(i)],""),forceDir);
    verForcesCellArray{i} = importdata(verForcesFilePaths(i));
end

%% FORCE COEFFICIENTS STATISTICS
%------------------------------------------------------------------------%
%**** Force coefficients statistics
%-! Calculate simple statistics like Cl_rms, Cd_mean.
%-! Organize force coefficients data in drag and lift and for each 
%-! cylinder part. 
%------------------------------------------------------------------------%
curveForces = cell([nCases,1]);
horForces = curveForces;
verForces = curveForces;

totForceTime = zeros(nCases,1);

dragCellArray = cell([nCases,1]);
liftCellArray = dragCellArray;
timeCellArray = dragCellArray;
timeCellArrayFull = dragCellArray;

for i = 1:nCases % Extract data from cell structs.
    curveForces{i} = curveForcesCellArray{i}.data;
    horForces{i} = horForcesCellArray{i}.data;
    verForces{i} = verForcesCellArray{i}.data;
end

for i = 1:nCases  % Separate drag and lift in cell arrays,
                  % and calculate net drag&lift for tot. cyl. config.
                  
    aD = curveForces{i}(forceStarts(i):end,3);
    bD = horForces{i}(forceStarts(i):end,3);
    cD = verForces{i}(forceStarts(i):end,3);
    
    aL = curveForces{i}(forceStarts(i):end,4);
    bL = horForces{i}(forceStarts(i):end,4);
    cL = verForces{i}(forceStarts(i):end,4);
    
    timeCellArrayFull{i} = curveForces{i}(:,1);
    timeCellArray{i} = curveForces{i}(forceStarts(i):end,1);
    
    totDrag = aD*curveCorrCoeff + bD*horCorrCoeff + cD*verCorrCoeff;
    totLift = aL*curveCorrCoeff + bL*horCorrCoeff + cL*verCorrCoeff;
    totForceTime(i) = length(totDrag);

    dragCellArray{i} = [ aD ...
                         bD ...
                         cD ...
                         totDrag ];
    liftCellArray{i} = [ aL ...
                         bL ...
                         cL ...
                         totLift ];
end
clear aD bD cD aL bL cL
clear curveForcesCellArray totDrag totLift

Cd_m = zeros(nCases,4);
Cl_m = zeros(nCases,4);
Cl_rms = zeros(nCases,4);

for i = 1:nCases % Calculate mean force coefficients
    Cd_m(i,:) = sum( dragCellArray{i} ) / totForceTime(i);
    Cl_m(i,:) = sum( liftCellArray{i} ) / totForceTime(i);
    Cl_rms(i,:) = sqrt( sum( liftCellArray{i}.^2 ) / totForceTime(i) );
end

%% FORCE COEFFICIENTS FREQUENCY ANALYSIS
%------------------------------------------------------------------------%
%**** Force coefficients frequency analysis
%-! Running discrete Fourier transforms on the lift coefficient data.
%-! Stores the frequency spectrum of the oscillation of Cl for each 
%-! cylinder part, finds the dominating frequency and writes out 
%-! frequency peak values and statistics to 'forceCoeffsAnalysis.txt'.
%------------------------------------------------------------------------%

nParts = length(parts);

% Frequency ranges of the lift coefficients
DT = zeros(1,nCases);
FS = DT;
LL = DT;
T = cell([nCases,1]);
FV = T;
F = FV;

for i = 1:nCases % Create frequency range
    DT(i) = timeCellArray{i}(end)-timeCellArray{i}(end-1);
    FS(i) = 1/DT(i);
    LL(i) = totForceTime(i);
    T{i} = (0:LL(i)-1)*DT(i);
    F{i} = FS(i)*(0:(LL(i)/2))/(LL(i));
    FV{i} = F{i}*(D/Uinf(i));
end

% FFT of lift coefficients for each part for each case
liftFFT_X = cell([nCases,1]); % X-vec for FFT
liftFFT_Y = cell([nCases,1]); % Y-vec for FFT, where Y = FFT(X)

for i = 1:nCases % Perform FFT for each case
    for j = 1:nParts % Loop through cylinder parts
        liftFFT_X{i}(:,j) = liftCellArray{i}(:,j) - Cl_m(i,j); % rmv avg.
        liftFFT_Y{i}(:,j) = fft(liftFFT_X{i}(:,j)); % FFT of signal
    end
end

P2_F = cell([nCases,1]);
P1_F = cell([nCases,1]);
partVecOnes = cell([nCases,1]);
partVec = cell([nCases,1]);
Fpeak = cell([nCases,nParts]);
Floc = Fpeak;
peakFreqLocs_F = zeros(nCases,nParts);
peak_F = zeros(nCases,nParts);
peakF_F = zeros(nCases,nParts);
for i = 1:nCases % Calc |FFT(lift)| and merge to single
                 % sided spectrum P1_F
    P2_F{i} = abs(liftFFT_Y{i});
    for j = 1:nParts
        P1_F{i}(:,j) = P2_F{i}(1:floor(LL(i)/2+1),j);
        P1_F{i}(2:end-1,j) = 2*P1_F{i}(2:end-1,j); % One-sided spectrum
        P1_F{i}(:,j) = P1_F{i}(:,j)./max(max(P1_F{i}(:,:)))*100; % Normalize
        partVecOnes{i} = ones(floor(LL(i)/2+1),length(parts));
        partVec{i}(:,j) = partVecOnes{i}(:,j)*parts(j);
    end

end

for i = 1:nCases % Find frequency peaks in the transform
    for j = 1:nParts
        [ Fpeak{i,j},Floc{i,j} ] = findpeaks(P1_F{i}(:,j),'SortStr','descend');
        peakFreqLocs_F(i,j) = Floc{i,j}(1);
        peak_F(i,j) = Fpeak{i,j}(1);
        peakF_F(i,j) = FV{i}(peakFreqLocs_F(i,j));
    end
end

fid = fopen('forceCoeffsAnalysis.txt','w');
fprintf(fid,'FORCE COEFFICIENTS ANALYSIS\n\n');
for i = 1:nCases % Write force statistics to file

    fprintf(fid,'-------------------------------------\n');
    fprintf(fid,'CASE: %s\n',caseNames(i));
    fprintf(fid,'-------------------------------------\n\n');
    fprintf(fid,'        cur        hor        ver     tot\n');
    fprintf(fid,'Cl_rms: %6.4f      %6.4f      %6.4f   %6.4f\n', ...
        Cl_rms(i,1),Cl_rms(i,2),Cl_rms(i,3),Cl_rms(i,4));
    fprintf(fid,'Cl_m:   %6.4f      %6.4f      %6.4f   %6.4f\n', ...
        Cl_m(i,1),Cl_m(i,2),Cl_m(i,3),Cl_m(i,4));
    fprintf(fid,'Cd_m:   %6.4f      %6.4f      %6.4f   %6.4f\n\n', ...
        Cd_m(i,1),Cd_m(i,2),Cd_m(i,3),Cd_m(i,4));
    fprintf(fid,'f_peak: %6.4f      %6.4f      %6.4f   %6.4f\n', ...
        peakF_F(i,1),peakF_F(i,2),peakF_F(i,3),peakF_F(i,4));
    fprintf(fid,'-------------------------------------\n\n\n');
    
end
fclose(fid);

%% GET VELOCITY PROBE DATA
%------------------------------------------------------------------------%
%**** Get velocity probe data.
%-! Move relevant files to directory set in 'velDir'.
%-! 
%------------------------------------------------------------------------%
velDir = 'velocityAnalysis/';

if (exist(velDir,'dir'))
    rmdir velocityAnalysis s
    mkdir velocityAnalysis/
else
    mkdir velocityAnalysis
end

% Uniform curve probes
% Names ex.: uniProbeM01.dat
uniProbeFilePaths = strings(1,nCases);
uniProbeCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,uniProbeFilePaths(i)] = fileMover(caseNames(i),'probesCurve',timeDirs(i), ...
    'U',join(['uniProbe' caseNames(i)],""),velDir);
    uniProbeCellArray{i} = load(uniProbeFilePaths(i));
end

% Upper fine theta
% Names ex.: fineProbeM01.dat
fineProbeFilePaths = strings(1,nCases);
fineProbeCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,fineProbeFilePaths(i)] = fileMover(caseNames(i),'probesCurveFine',timeDirs(i), ...
    'U',join(['fineProbe' caseNames(i)],""),velDir);
    fineProbeCellArray{i} = load(fineProbeFilePaths(i));
end

% U vertical 1D
% Names ex.: verProbe1D_M01.dat
ver1DProbeFilePaths = strings(1,nCases);
ver1DProbeCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,ver1DProbeFilePaths(i)] = fileMover(caseNames(i),'probesVer1D',timeDirs(i), ...
    'U',join(['verProbe1D_' caseNames(i)],""),velDir);
    ver1DProbeCellArray{i} = load(ver1DProbeFilePaths(i));
end

% U vertical 3D
% Names ex.: verProbe3D_M01.dat
ver3DProbeFilePaths = strings(1,nCases);
ver3DProbeCellArray = cell([nCases,1]);
for i = 1:nCases
    [~,ver3DProbeFilePaths(i)] = fileMover(caseNames(i),'probesVer3D',timeDirs(i), ...
    'U',join(['verProbe3D_' caseNames(i)],""),velDir);
    ver3DProbeCellArray{i} = load(ver3DProbeFilePaths(i));
end

%% TIME AVERAGED VELOCITY PROBE DATA
%------------------------------------------------------------------------%
%**** Time avg. velocity probe data
%-! Calculate average velcity data at all probe locations.
%-! Calculate the mean axial flow along the cylinder. That is the 
%-! tangential velocity along the curved cylinder and the vertical 
%-! flow along the straight vertical extension.
%------------------------------------------------------------------------%

% Uniform Curve
uniUmeans = cell([nCases,1]);
uniTimeLengths = zeros(1,nCases);
Uax = cell([nCases,1]);
UaxNorm = Uax;

for i = 1:nCases % Calculate Uax
    [uniTimeLengths(i),~] = size( ... 
       uniProbeCellArray{i}(uniStart(i):end,1));
   
    uniUmeans{i} = sum(uniProbeCellArray{i}(uniStart(i):end,2:end))/uniTimeLengths(i);
    
    Uax{i} = uniUmeans{i}(1:3:end).*cos(uniThetaRad{i}) + ...
        uniUmeans{i}(3:3:end).*sin(uniThetaRad{i});
    
    UaxNorm{i} = Uax{i}/Uinf(i);
end

% Upper fine curve
fineUmeans = cell([nCases,1]);
fineTimeLengths = zeros(1,nCases);
fineUax = cell([nCases,1]);
fineUaxNorm = fineUax;

for i = 1:nCases % Calculate Uax
    [fineTimeLengths(i),~] = size( ... 
       fineProbeCellArray{i}(fineStart(i):end,1));
   
    fineUmeans{i} = sum(fineProbeCellArray{i}(fineStart(i):end,2:end))/fineTimeLengths(i);
    fineUax{i} = fineUmeans{i}(1:3:end).*cos(fineThetaRad{i}) + ...
        fineUmeans{i}(3:3:end).*sin(fineThetaRad{i});
    fineUaxNorm{i} = fineUax{i}/Uinf(i);
end

% Vertical 1D
ver1DUmeans = cell([nCases,1]);
ver1DTimeLengths = zeros(1,nCases);
ver1DUax = cell([nCases,1]);
ver1DUaxNorm = ver1DUax;

for i = 1:nCases % Extract Uax
    [ver1DTimeLengths(i),~] = size( ... 
       ver1DProbeCellArray{i}(ver1DStart(i):end,1));
   
    ver1DUmeans{i} = sum(ver1DProbeCellArray{i}(ver1DStart(i):end,2:end))/ver1DTimeLengths(i);
    ver1DUax{i} = ver1DUmeans{i}(3:3:end);
    ver1DUaxNorm{i} = ver1DUax{i}/Uinf(i);
end

%% Velocity frequency analysis
%------------------------------------------------------------------------%
%**** Velocty frequency analysis
%-! Running discrete Fourier transforms on the v-component of the velocity
%-! at 3D behind the vertical extension.
%-! Stores the frequency spectrum of the oscillation of v for each 
%-! probe, finds the dominating frequency and writes out 
%-! frequency peak values to 'velocityAnalysis.txt'.
%------------------------------------------------------------------------%

% Vertical 3D
ver3DUmeans = cell([nCases,1]);
ver3DTimeLengths = zeros(1,nCases);
ver3DUax = cell([nCases,1]);
ver3DUaxNorm = ver3DUax;

for i = 1:nCases % Uax 3D
    [ver3DTimeLengths(i),~] = size( ... 
       ver3DProbeCellArray{i}(ver3DStart(i):end,1));
   
    ver3DUmeans{i} = sum(ver3DProbeCellArray{i}(ver3DStart(i):end,2:end))/...
        ver3DTimeLengths(i);
    ver3DUax{i} = ver3DUmeans{i}(3:3:end);
    ver3DUaxNorm{i} = ver3DUax{i}/Uinf(i);
end

% Frequency ranges of v for each case
dt = zeros(1,nCases);
Fs = dt;
L = dt;
t = cell([nCases,1]);
fv = t;
f = fv;
ver3Dv = cell([nCases,1]);

for i = 1:nCases % Frequency range
    ver3Dv{i} = ver3DProbeCellArray{i}(ver3DStart(i):end,3:3:end);
    dt(i) = ver3DProbeCellArray{i}(end,1) - ver3DProbeCellArray{i}(end-1,1);
    %dt(i) = 0.1;
    Fs(i) = 1/dt(i);
    L(i) = ver3DTimeLengths(i);
    t{i} = (0:L(i)-1)*dt(i);
    f{i} = Fs(i)*(0:(L(i)/2))/(L(i));
    fv{i} = f{i}*(D/Uinf(i));
end

% FFT of v-signal for each case at each Z-position
ver3D_X = cell([nCases,1]); % X-vec for FFT
ver3D_Y = cell([nCases,1]); % Y-vec for FFT, where Y = FFT(X)

nVer3DProbes = zeros(1,nCases);
for i = 1:nCases % FFT(v)
    [~,nVer3DProbes(i)] = size(ver3Dv{i});
    
    if i == 1
        timeAvg3Dv = zeros(nCases,nVer3DProbes(i));
    end
    
    for j = 1:nVer3DProbes(i)
        timeAvg3Dv(i,j) = (sum(ver3Dv{i}(:,j)))/L(i); % Calc avg signal
        ver3D_X{i} = ver3Dv{i} - timeAvg3Dv(i,j); % rmv avg signal
        ver3D_Y{i}(:,j) = fft(ver3D_X{i}(:,j)); % FFT of signal
    end
end

P2 = cell([nCases,1]);
P1 = cell([nCases,1]);
zVecOnes = cell([nCases,1]);
Z = cell([nCases,1]);
for i = 1:nCases % Frequency spectrum
    P2{i} = abs(ver3D_Y{i}); % Two-sided spectrum, non-normalized
    for j = 1:nVer3DProbes(i)
        P1{i}(:,j) = P2{i}(floor(1:L(i)/2+1),j); 
        P1{i}(2:end-1,j) = 2*P1{i}(2:end-1,j); % One-sided spectrum
        P1{i}(:,j) = P1{i}(:,j)./max(max(P1{i}(:,:))); % Normalize
        zVecOnes{i} = ones(floor(L(i)/2+1),nVer3DProbes(i));
        Z{i}(:,j) = zVecOnes{i}(:,j)*zVer3D{i}(j);
    end
end

% vPeak = cell([nCases,nVer3DProbes]);
% vLoc = vPeak;
% peakFreqLocs_v = zeros(nCases,nVer3DProbes);
% peak_v = zeros(nCases,nVer3DProbes);
% peakF_v = zeros(nCases,nVer3DProbes);
% for i = 1:nCases % Find frequency peaks in the transform
%     for j = 1:nVer3DProbes
%         [ vPeak{i,j},vLoc{i,j} ] = findpeaks(P1{i}(:,j),'SortStr','descend');
%         peakFreqLocs_v(i,j) = vLoc{i,j}(1);
%         peak_v(i,j) = vPeak{i,j}(1);
%         peakF_v(i,j) = fv{i}(peakFreqLocs_v(i,j));
%     end
% end

peakFreqLocs_v = cell([nCases,1]);
peak_v = cell([nCases,1]);
peakF_v = cell([nCases,1]);
for i = 1:nCases
    vPeak = cell([nVer3DProbes(i),1]);
    vLoc = cell([nVer3DProbes(i),1]);

    for j = 1:nVer3DProbes(i)
       [ vPeak{j},vLoc{j} ] = findpeaks(P1{i}(:,j),'SortStr','descend');
        
        peakFreqLocs_v{i}(j) = vLoc{j}(1);
        peak_v{i}(j) = vPeak{j}(1);
        peakF_v{i}(j) = fv{i}(peakFreqLocs_v{i}(j));
    end
end

fid = fopen('velocityAnalysis.txt','w');
fprintf(fid,'VELOCITY ANALYSIS\n\n');
for i = 1:nCases % Write frequency peaks to file
    fprintf(fid,'-------------------------------------\n');
    fprintf(fid,'CASE: %s\n',caseNames(i));
    fprintf(fid,'-------------------------------------\n');
    
    for j = 1:nVer3DProbes(i)
        fprintf(fid,'f_peak (Z/D = %6.4f): %6.4f \n', zVer3D{i}(j),peakF_v{i}(j));
    end
    fprintf(fid,'\n');
end
fclose(fid);