%% SET CASES AND PLOT SETTINGS
%-!
%-! ----------------------------------------------------------------
%-! ||  Case Name   |  Case number  |  Case Name   |  Case number ||
%-! ----------------------------------------------------------------
%-! |    M01               1               C01            8        |
%-! |    M02               2               C02            9        |
%-! |    M03               3               C03           10        |
%-! |    M04               4               C04           11        |
%-! |    M05               5               S01           12        |
%-! |    M06               6               S02           13        |
%-! |    M07               7               S03           14        |
%-! '--------------------------------------------------------------'
%-!
%------------------------------------------------------------------------%
plotCaseNames = ["S01","S02"];
plotCaseNumbers = [7 11];
nPlotCases = length(plotCaseNumbers);
nCases = 14;

% Plot settings
LineWidthGraph = 1.5;
LineWidthMarker = 1.5;
LineStyles = linspecer(nPlotCases);
Markers = ["o","s","d","*",">",".","x"];
MarkerSize = 7;
labelFontSize = 20;
labelFontSize2 = 16;
titleFontSize = 12;
legendFontSize = 18;
axisFontSize = 16;

%% PLOT FREQUENCY DENSITY SPECTRUM FOR FORCECOEFFS
for i = plotCaseNumbers 
    figure ('Name',caseNames(i),'color','white')
    plot3(partVec{i},FV{i},P1_F{i},'color',LineStyles(1,:),'LineWidth',LineWidthGraph) 
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize)
     axis([0 nParts 0 0.5 0 110])
%     saveas(gcf,join(['figs/' caseNames(i) '_figs/' caseNames(i) '_DFT_CL.png'],""))
end

%% PLOT MEAN AXIAL VELOCITY ALONG 0-90 DEG.

figure ('Name','U_{axial}','color','white')
count = 1;
for i = plotCaseNumbers
   plot(uniThetaDeg{i},UaxNorm{i},'color',LineStyles(count,:),...
       'marker',Markers(count),'MarkerSize',MarkerSize,'LineWidth',LineWidthGraph)
   count = count + 1;
   hold on
end
%legend({'$K>0$','$K<0$','Uniform RE200','Uniform RE500'},...
%legend({'M01','M02','M03','M04','M05','M06','M07'},...
%    'fontSize',legendFontSize,'Location','northeast');
%legend('boxoff');
grid on
hold off
axis([-2 92 0.3 1.45])
set(gca,'fontsize',axisFontSize);
ylabel('$U_{ax}/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize)
xlabel('$\theta [^\circ]$','Interpreter','latex', ...
        'fontSize',labelFontSize)
% if nCases == 1
%     saveas(gcf,join(['figs/' caseNames(1) '_figs/' caseNames(1) '_Uax_curve.png'],""))
% else
%     saveas(gcf,'figs/caseComparisons/Uax_comp_curve.png')
% end
%% PLOT MEAN AXIAL VELOCITY ALONG 80-90 DEG. 
figure ('Name','U_ax Upper Theta','color','white')
count = 1;
for i = plotCaseNumbers
   plot(fineThetaDeg{i},fineUaxNorm{i},'color',LineStyles(count,:),...
       'marker',Markers(count),'MarkerSize',MarkerSize,'LineWidth',LineWidthGraph) 
   count = count + 1;
   hold on
end
hold off

axis([fineThetaStartDeg-1 fineThetaEndDeg+1 0.3 0.9])
ylabel('$U_{ax}/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize)
xlabel('$\theta [^\circ]$','Interpreter','latex', ...
        'fontSize',labelFontSize)
    
%legend({'$K>0$','$K<0$','Uniform RE200','Uniform RE500'},...
%legend({'M01','M02','M03','M04','M05','M06','M07'},...
%    'Interpreter','latex','fontSize',legendFontSize,'Location','northeast');
%legend('boxoff');
set(gca,'fontsize',axisFontSize);
grid on

% if nCases == 1
%     saveas(gcf,join(['figs/' caseNames(1) '_figs/' caseNames(1) '_Uax_curve_upper.png'],""))
% else
%     saveas(gcf,'figs/caseComparisons/Uax_comp_curve_upper.png')
% end

%% PLOT MEAN AXIAL VELOCITY ALONG VERTICAL EXTENSION. 
close all
figure ('Name','U_ax Vertical section','color','white')
count = 1;
for i = plotCaseNumbers
   plot(zVer1D{i},ver1DUaxNorm{i},'color',LineStyles(count,:),...
       'marker',Markers(count),'MarkerSize',MarkerSize,'LineWidth',LineWidthGraph) 
   count = count + 1;
   hold on
end
hold off

ylabel('$U_{ax}/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize)
xlabel('$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize)
axis([0 (zVer1D{i}(end)+0.5) -0.2 0.9])
    
%legend({'$K>0$','$K<0$','Uniform RE200','Uniform RE500'},...
%legend({'M01','M02','M03','M04','M05','M06','M07'},...
%    'Interpreter','latex','fontSize',legendFontSize,'Location','northeast');
%legend('boxoff');
set(gca,'fontsize',axisFontSize);
grid on
% if nCases == 1
%     saveas(gcf,join(['figs/' caseNames(1) '_figs/' caseNames(1) '_Uax_ver.png'],""))
% else
%     saveas(gcf,'figs/caseComparisons/Uax_comp_ver.png')
% end

%% PLOT FREQUENCY DENSITY SPECTRUM FOR THE VELOCITY
for i = plotCaseNumbers
    figure ('Name',caseNames(i),'color','white')
    plot3(Z{i},fv{i},P1{i}*100,'color',LineStyles(1,:),...
       'LineWidth',LineWidthGraph) 
    
    zlabel('$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize)
    xlabel('$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize)
    
    grid on
    axis([0 zVer3D{i}(end) 0 0.3 0 101])
    view(47,46);
%     saveas(gcf,join(['figs/' caseNames(i) '_figs/' caseNames(i) '_DFT_v.png'],""))
end

%% MULTIPLOTS OF FREQUENCY SPECTRA M01-M04
figure('color','white')
ax1 = subplot(2,2,1);
plot3(ax1,Z{1},fv{1},P1{1}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax1,'M01','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax1,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax1,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax1,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])

ax2 = subplot(2,2,2);
plot3(ax2,Z{2},fv{2},P1{2}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax2,'M02','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax2,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax2,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax2,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])
    
ax3 = subplot(2,2,3);
plot3(ax3,Z{3},fv{3},P1{3}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax3,'M03','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax3,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax3,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax3,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])
    
ax4 = subplot(2,2,4);
plot3(ax4,Z{4},fv{4},P1{4}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax4,'M04','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax4,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax4,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax4,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])

    %% MULTIPLOTS OF FREQUENCY SPECTRA M05-M07
figure('color','white')
ax1 = subplot(2,2,1);
plot3(ax1,Z{5},fv{5},P1{5}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax1,'M05','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax1,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax1,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax1,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])

ax2 = subplot(2,2,2);
plot3(ax2,Z{6},fv{6},P1{6}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax2,'M06','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax2,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax2,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax2,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])
    
ax3 = subplot(2,2,3);
plot3(ax3,Z{7},fv{7},P1{7}*100,'color',LineStyles(2,:),...
       'LineWidth',LineWidthGraph)
title(ax3,'M07','Interpreter','latex', ...
        'fontSize',titleFontSize)
    zlabel(ax3,'$DFT(v)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel(ax3,'$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel(ax3,'$z/D$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 6 0 0.2 0 105])

%% MULTIPLOTS OF FORCE FREQUENCY SPECTRA M01-M04
figure('color','white')
ax1 = subplot(2,2,1);
    plot3(partVec{1},FV{1},P1_F{1},'color',LineStyles(2,:),'LineWidth',LineWidthGraph)
    title(ax1,'M01','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])

ax2 = subplot(2,2,2);
    plot3(partVec{2},FV{2},P1_F{2},'color',LineStyles(2,:),'LineWidth',LineWidthGraph) 
    title(ax2,'M02','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])
    
ax3 = subplot(2,2,3);
    plot3(partVec{3},FV{3},P1_F{3},'color',LineStyles(2,:),'LineWidth',LineWidthGraph) 
    title(ax3,'M03','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])
    
ax4 = subplot(2,2,4);
    plot3(partVec{4},FV{4},P1_F{4},'color',LineStyles(2,:),'LineWidth',LineWidthGraph) 
    title(ax4,'M04','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])
    
%% MULTIPLOTS OF FORCE FREQUENCY SPECTRA M05-M07
figure('color','white')
ax1 = subplot(2,2,1);
    plot3(partVec{5},FV{5},P1_F{5},'color',LineStyles(2,:),'LineWidth',LineWidthGraph)
    title(ax1,'M05','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])

ax2 = subplot(2,2,2);
    plot3(partVec{6},FV{6},P1_F{6},'color',LineStyles(2,:),'LineWidth',LineWidthGraph) 
    title(ax2,'M06','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])
    
ax3 = subplot(2,2,3);
    plot3(partVec{7},FV{7},P1_F{7},'color',LineStyles(2,:),'LineWidth',LineWidthGraph) 
    title(ax3,'M07','Interpreter','latex', ...
        'fontSize',titleFontSize)
    grid on
    zlabel('$DFT(C_L)$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    ylabel('$fD/U_{0}$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    xlabel('$curve, hor, ver, tot$','Interpreter','latex', ...
        'fontSize',labelFontSize2)
    axis([0.5 4 0 0.2 0 105])
    
