clear
close all
clc

z = load('inletZ');
y = load('inletY');

K = -0.0236406;
% K = -0.018237;                % Non-dim. shear flow slope
D = 1;                  % Cylinder diameter
U0 = 7;                 % Bottom inlet velocity
Uinf_top = 2;           % Top inlet velocity
h = 47;                 % Non-dim. profile height. (e.g. domain height.)

fileName = 'S03_profile.png';

R = 12;

Uc = (Uinf_top - U0) * D / (K*h);

Uavg = abs(Uinf_top-U0)/2 + min(Uinf_top,U0);

Ux = K * ((z+23)/D) * Uc + U0;
localRe = D*Ux/0.01;

theta = 0:-0.5:-90;
xCoorTop = (R)*cosd(theta);
yCoorTop = (R)*sind(theta);
xCoorBot = (R+D)*cosd(theta);
yCoorBot = (R+D)*sind(theta);

xCoorHor = -10:1:0;
yCoorHorTop = -(R)*ones(1,11);
yCoorHorBot = -(R+D)*ones(1,11);

yCoorVer = 0:1:24;
xCoorVerTop = (R)*ones(1,25);
xCoorVerBot = (R+D)*ones(1,25);

xCylGeoTop = [xCoorHor fliplr(xCoorTop) xCoorVerTop];
yCylGeoTop = [yCoorHorTop fliplr(yCoorTop) yCoorVer];
xCylGeoBot = [xCoorHor fliplr(xCoorBot) xCoorVerBot];
yCylGeoBot = [yCoorHorBot fliplr(yCoorBot) yCoorVer];

xProfileTop = 0:0.1:Uinf_top;
xProfileBot = 0:0.1:U0;

%%
figure
plot(Ux,z,'-k','LineWidth',1.5)
hold on
plot(xCylGeoTop+20,yCylGeoTop,'-k','LineWidth',1.5)
hold on
plot(xCylGeoBot+20,yCylGeoBot,'-k','LineWidth',1.5)

arrow([0 23.75],[Uinf_top,23.75],'Length',10,'Width',1);
text(Uinf_top + Uinf_top/2,22,'$U_{top}$','Interpreter','latex', ...
            'fontSize',20)

% arrow([0 0.5],[Uavg,0.5],'Length',15,'Width',1);
% text(Uavg + Uavg/2,0,'$U_0=2$ $m/s$','Interpreter','latex', ...
%             'fontSize',20)        
        
arrow([0 0.5],[Uavg,0.5],'Length',15,'Width',1);
text(Uavg + Uavg/2,0,'$U_c=4.5$ $m/s$','Interpreter','latex', ...
            'fontSize',20)

arrow([0 -22.75],[U0,-22.75],'Length',15,'Width',1);
text(U0 + U0/2,-22,'$U_{bottom}$','Interpreter','latex', ...
            'fontSize',20)

daspect([1 1 1]);
ylabel('$z/D$','Interpreter','latex', ...
            'fontSize',15)
xlabel('$U_0(z)$','Interpreter','latex', ...
            'fontSize',15)
axis([0 35 -24 25]);
grid on
saveas(gcf,fileName)

%% Local Reynolds number figure
close all

figure
plot(localRe,z,'-k','LineWidth',1.5)

arrow([0 23.75],[Uinf_top*100,23.75],'Length',15,'Width',1);
text(localRe(end)/1.5,22,'$Re_l(24D) = 200$','Interpreter','latex', ...
            'fontSize',12)

arrow([0 0.5],[Uavg*100,0.5],'Length',15,'Width',1);
text(Uavg*100/5,2,'$Re_l(0.5D) = 450$','Interpreter','latex', ...
            'fontSize',12)

arrow([0 -22.75],[U0*100,-22.75],'Length',15,'Width',1);
text(U0*100/6,-21,'$Re_l(-23D)=700$','Interpreter','latex', ...
            'fontSize',12)
        
arrow([0 15],[locVel(15)*100,15],'Length',15,'Width',1);
text(locVel(15)*100/5,13,'$Re_l(15D)=295.7$','Interpreter','latex', ...
            'fontSize',12)
        
arrow([0 -14],[locVel(-14)*100,-14],'Length',15,'Width',1);
text(locVel(-14)*100/5,-12,'$Re_l(-14D)=604.3$','Interpreter','latex', ...
            'fontSize',12)

ylabel('$z/D$','Interpreter','latex', ...
            'fontSize',15)
xlabel('$Re_l(z)$','Interpreter','latex', ...
            'fontSize',15)
axis([0 800 -24 25]);
grid on
saveas(gcf,'S03_RE_profile.png')




%%
fid = fopen('shearUx','w');
for i = 1:length(Ux)
    fprintf(fid,'( %8.4f %8.4f %8.4f )\n', Ux(i), 0, 0);
end

%%
locVel = @localVelocity;
function y = localVelocity(z)
K = -0.0236406;
% K = -0.018237;                % Non-dim. shear flow slope
D = 1;                  % Cylinder diameter
U0 = 7;                 % Bottom inlet velocity
Uinf_top = 2;           % Top inlet velocity
h = 47;                 % Non-dim. profile height. (e.g. domain height.)
Uc = (Uinf_top - U0) * D / (K*h);

y = K * ((z+23)/D) * Uc + U0;
end




